ipc.c: Use ftok() instead of SuperFastHash.
[dss.git] / snap.h
diff --git a/snap.h b/snap.h
index eca484a462b6d3ad77c23d75d5b0518058dd5057..626ecad003a52a1a465ea6f7f2e11f960a97df3c 100644 (file)
--- a/snap.h
+++ b/snap.h
@@ -1,32 +1,32 @@
 /*
- * Copyright (C) 2008 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2008-2010 Andre Noll <maan@tuebingen.mpg.de>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
+
 /** The possible states for snapshot creation/removal. */
-enum hook_status {
-       /** We are ready to take the next snapshot. */
-       HS_READY,
-       /** The pre-create/pre-remove hook has been started. */
-       HS_PRE_RUNNING,
-       /** The pre-create/pre-remove hook exited successfully. */
-       HS_PRE_SUCCESS,
-       /** The rsync/rm process is running. */
-       HS_RUNNING,
-       /** The rsync/rm process exited successfully. */
-       HS_SUCCESS,
-       /** The rsync/rm process needs to be restarted. */
-       HS_NEEDS_RESTART,
-       /** The post-create/post-remove hook has been started. */
-       HS_POST_RUNNING,
-};
+#define HOOK_STATUS_ARRAY \
+       HSA_ITEM(HS_READY, "ready for action"), \
+       HSA_ITEM(HS_PRE_RUNNING, "pre-hook running"), \
+       HSA_ITEM(HS_PRE_SUCCESS, "pre-hook completed successfully"), \
+       HSA_ITEM(HS_RUNNING, "in progress"), \
+       HSA_ITEM(HS_SUCCESS, "process terminated successfully"), \
+       HSA_ITEM(HS_NEEDS_RESTART, "restart needed"), \
+       HSA_ITEM(HS_POST_RUNNING, "post-hook running")
+
+
+#define HSA_ITEM(x, y) x
+enum hook_status {HOOK_STATUS_ARRAY};
+#undef HSA_ITEM
+#define HSA_ITEM(x, y) y
+
 
 /**
  * The status of a snapshot.
  *
  * The snapshot directories come in four different flavours, depending
- * on how the two staus flags are set. Examples:
+ * on how the two status flags are set. Examples:
  *
  * Complete, not being deleted: 1204565370-1204565371.Sun_Mar_02_2008_14_33-Sun_Mar_02_2008_14_43.
  * Complete, being deleted: 1204565370-1204565371.being_deleted.
@@ -37,7 +37,7 @@ enum snapshot_status_flags {
        /** The rsync process terminated successfully. */
        SS_COMPLETE = 1,
        /** The rm process is running to remove this snapshot. */
-       SS_BEING_DELETED = 2,
+       SS_BEING_DELETED = 2
 };
 
 /** Describes one snapshot. */
@@ -48,7 +48,7 @@ struct snapshot {
        int64_t creation_time;
        /**
         * Seconds after the epoch when creation of this snapshot completed.
* Only meaningful if the SS_COMPLTE bit is set.
         */
        int64_t completion_time;
        /** See \ref snapshot_status_flags. */
@@ -88,16 +88,7 @@ __malloc char *incomplete_name(int64_t start);
 __malloc char *being_deleted_name(struct snapshot *s);
 int complete_name(int64_t start, int64_t end, char **result);
 __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl);
-
-/**
- * Get the oldest snapshot in a snapshot list.
- */
-_static_inline_ struct snapshot *get_oldest_snapshot(struct snapshot_list *sl)
-{
-       if (!sl->num_snapshots)
-               return NULL;
-       return sl->snapshots[0];
-}
+int num_complete_snapshots(struct snapshot_list *sl);
 
 /**
  * Get the newest snapshot in a snapshot list.
@@ -48,7 +48,7 @@ struct snapshot {
        /**
         * Seconds after the epoch when creation of this snapshot completed.
-        * Only meaningful if the SS_COMPLTE bit is set.
+        * Only meaningful if the SS_COMPLETE bit is set.
         */
        int64_t completion_time;